==> canine2.db_2.2.11.tar.gz: canine2.db/man/canine2_dbconn.Rd <==
\name{canine2_dbconn}

\alias{canine2_dbconn}
\alias{canine2_dbfile}
\alias{canine2_dbschema}
\alias{canine2_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  canine2_dbconn()
  canine2_dbfile()
  canine2_dbschema(file="", show.indices=FALSE)
  canine2_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{canine2_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{canine2_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{canine2_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{canine2_dbschema} prints the schema definition of the
  package annotation DB.

  \code{canine2_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{canine2_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{canine2_dbfile}: a character string with the path to the
  package annotation DB.

  \code{canine2_dbschema}: none (invisible \code{NULL}).

  \code{canine2_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(canine2_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by canine2_dbconn() was created with:
  dbConnect(SQLite(), dbname=canine2_dbfile(), cache_size=64000, synchronous=0)

  canine2_dbschema()

  canine2_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> canine2.db_2.9.0.tar.gz: canine2.db/man/canine2_dbconn.Rd <==

\name{canine2_dbconn}

\alias{canine2_dbconn}
\alias{canine2_dbfile}
\alias{canine2_dbschema}
\alias{canine2_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  canine2_dbconn()
  canine2_dbfile()
  canine2_dbschema(file="", show.indices=FALSE)
  canine2_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{canine2_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{canine2_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{canine2_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{canine2_dbschema} prints the schema definition of the
  package annotation DB.

  \code{canine2_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{canine2_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{canine2_dbfile}: a character string with the path to the
  package annotation DB.

  \code{canine2_dbschema}: none (invisible \code{NULL}).

  \code{canine2_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(canine2_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by canine2_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=canine2_dbfile(), cache_size=64000,
  synchronous=0)

  canine2_dbschema()

  canine2_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
